import { FormName, SubformName, TeamId, Username } from '../commonInterfaces';
export interface FieldsType {
    field_name: string;
    answer: string;
    c_date?: string;
}
export interface GenericFormResponse {
    return_error: string;
    submitted: number | string;
    form_name: string;
    entity_id: string;
    sub_form: string;
    entity_type: string;
    entry_list: FieldsType[];
    command: string;
}
interface FormParams {
    formName: FormName;
    subformName?: SubformName;
}
interface ApiCallWithTeamParams extends FormParams {
    teamId: TeamId;
}
interface ApiCallWithUsernameParams extends FormParams {
    username: Username;
}
type ApiCallParams = ApiCallWithTeamParams | ApiCallWithUsernameParams;
type ApiWithDataParams = ApiCallParams & {
    entryList: FieldsType[];
};
export declare const apiStoreFormData: (params: ApiWithDataParams) => Promise<GenericFormResponse & {
    command: 'store';
}>;
export declare const apiGetFormData: (params: ApiCallParams) => Promise<GenericFormResponse & {
    command: 'store';
}>;
export declare const apiSubmitForm: (params: ApiCallParams) => Promise<GenericFormResponse & {
    command: 'submit';
}>;
export declare const apiUnsubmitForm: (params: ApiCallParams) => Promise<GenericFormResponse & {
    command: 'return_form';
}>;
export declare const apiDeleteForm: (params: ApiCallParams) => Promise<GenericFormResponse & {
    command: 'delete_form';
}>;
export interface GetInfoFormResponse {
    track: string;
    team_name: string;
    full_name: string;
    sub_forms: Array<{
        sub_form: string;
        submitted: number | string;
    }>;
    user_name: string;
    entity_id: string;
    entity_type: string;
}
export declare const apiGetFormInfo: (params: ApiCallParams) => Promise<GetInfoFormResponse>;
export interface UserInfoFormResponse {
    user_name: string;
    full_name: string;
    is_super: 'true' | 'false';
}
export declare const apiGetUserInfo: () => Promise<UserInfoFormResponse>;
export {};
