export declare enum SessionStatus {
    OFFLINE = "offline",
    SCHEDULED = "scheduled",
    LIVE = "live",
    ARCHIVED = "archived"
}
export declare enum SessionType {
    OTHER = "other",
    MEETING = "meeting",
    JUDGING_SESSION = "judging-session",
    AWARDS_CEREMONY = "awards-ceremony",
    OPENING_CEREMONY = "opening-ceremony",
    ANNOUNCEMENT = "announcement",
    LIVE_STREAM = "live-stream",
    MEETUP = "meetup",
    Q_AND_A = "q-and-a",
    WORKSHOP = "workshop",
    CONGRESS = "congress",
    CONFERENCE = "conference",
    FORUM = "forum",
    PANEL = "panel",
    EXHIBITION = "exhibition",
    CULTURAL = "cultural",
    WATCH_PARTY = "watch-party",
    PARTY = "party",
    LECTURE = "lecture",
    SEMINAR = "seminar",
    WEBINAR = "webinar"
}
export declare enum Sponsors {
    IDT = "idt",
    IDTIGEM = "idt-igem",
    GINKGO = "ginkgo",
    OPEN = "open",
    COTTRELL = "rc-tech",
    BECKMAN = "beckman",
    FBI = "fbi",
    GENSCRIPT = "genscript",
    MATHWORKS = "mathworks",
    HELLO_TOMORROW = "hello-tomorrow",
    IWBDA = "iwbda"
}
export interface DateAudit {
    created: Date;
    updated: Date;
}
export interface DayEvent {
    uuid: string;
    title: string;
    description?: string;
    type: SessionType;
    status: SessionStatus;
    startTime: Date;
    endTime?: Date;
    metadata?: {
        category?: string;
        comment?: string;
        sponsor?: Sponsors;
        speakers?: Array<{
            name: string;
            description: string;
        }>;
        recording?: {
            link?: string;
            thumbnail?: string;
        };
        sessionType?: string;
    };
    audit: DateAudit;
    eventUUID: string;
    event?: Event;
    liveStreamUUID?: string;
    liveStream?: LiveStream;
    zoomMeetingID?: string;
    zoomMeeting?: any;
}
export interface Event {
    uuid: string;
    title: string;
    description: string;
}
export declare enum LiveStreamVendor {
    PEERTUBE = "peertube",
    AWS_IVS = "aws_avi"
}
export declare enum LiveStreamStatus {
    PENDING = "pending",
    READY = "ready",
    LIVE = "live",
    CLOSING = "closing",
    ARCHIVED = "archived"
}
export interface LiveStream {
    uuid: string;
    title: string;
    description?: string;
    vendor: LiveStreamVendor;
    playbackURL: string;
    metadata?: object;
    status?: LiveStreamStatus;
}
export interface Session {
    uuid: string;
    title: string;
    description?: string;
    type: SessionType;
    status: SessionStatus;
    startTime: Date;
    endTime: Date;
    metadata?: object;
    audit: DateAudit;
    eventUUID: string;
    event?: Event;
    liveStreamUUID?: string;
    liveStream?: LiveStream;
    zoomMeetingID?: string;
}
